@@ -68,13 +68,9 @@ static gboolean check_lxde_dbus()
         return FALSE;
     }
 
-    DBusMessage * test = dbus_message_new_method_call	(
-        "org.lxde.SessionManager",
-        "/org/lxde/SessionManager",
-        "org.lxde.SessionManager",
-        "Logout");
+    dbus_bool_t ret = dbus_bus_name_has_owner(connection,"org.lxde.SessionManager",NULL);
 
-    if (dbus_message_has_interface(test, "org.lxde.SessionManager"))
+    if (ret == TRUE)
     {
         return TRUE;
     }
@@ -126,7 +122,7 @@ static void save_cursor_theme_name()
     {
         char* index_theme = g_build_filename(dir_path, "index.theme", NULL);
         char* content = g_strdup_printf(
-            "# This file is written by LXAppearance. Do not edit."
+            "# This file is written by LXAppearance. Do not edit.\n"
             "[Icon Theme]\n"
             "Name=Default\n"
             "Comment=Default Cursor Theme\n"
